summaryrefslogtreecommitdiff
path: root/keyboards/keyboardio
diff options
context:
space:
mode:
authorRyan <fauxpark@gmail.com>2022-10-17 00:14:40 +1100
committerGitHub <noreply@github.com>2022-10-16 14:14:40 +0100
commit74223c34a969c0877bde035c721c21a1f25890fa (patch)
tree1daea9db13a0adb529e5aba4aa1e6f893cb7ed8c /keyboards/keyboardio
parent39c22f5cf5011427ece26c510d0b1ab42edf34db (diff)
Remove legacy keycodes, part 6 (#18740)
* `KC_RSHIFT` -> `KC_RSFT` * `KC_RCTRL` -> `KC_RCTL` * `KC_LSHIFT` -> `KC_LSFT` * `KC_LCTRL` -> `KC_LCTL`
Diffstat (limited to 'keyboards/keyboardio')
-rw-r--r--keyboards/keyboardio/atreus/keymaps/ardumont/keymap.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/keyboards/keyboardio/atreus/keymaps/ardumont/keymap.c b/keyboards/keyboardio/atreus/keymaps/ardumont/keymap.c
index 373438e4b4..b630b6f698 100644
--- a/keyboards/keyboardio/atreus/keymaps/ardumont/keymap.c
+++ b/keyboards/keyboardio/atreus/keymaps/ardumont/keymap.c
@@ -43,7 +43,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_Q, KC_W, KC_E, KC_R, KC_T, KC_Y, KC_U, KC_I, KC_O, KC_P ,
KC_A, KC_S, KC_D, KC_F, KC_G, KC_H, KC_J, KC_K, KC_L, KC_SCLN ,
Z_SFT, KC_X, KC_C, KC_V, KC_B, KC_GRAVE, KC_BSLS, KC_N, KC_M, KC_COMM, KC_DOT, SLSH_SFT,
- KC_LCTRL, KC_ESC, KC_LGUI, KC_LALT, KC_SPC, FN0, FN0, KC_SPC, KC_LALT, KC_MINS, KC_QUOT, KC_LCTRL
+ KC_LCTL, KC_ESC, KC_LGUI, KC_LALT, KC_SPC, FN0, FN0, KC_SPC, KC_LALT, KC_MINS, KC_QUOT, KC_LCTL
),
/*
@@ -83,10 +83,10 @@ bool substitute_keycode(uint16_t keycode, keyrecord_t *record, uint8_t mod_state
// of the delete key status: registered or not?
static bool key_registered;
// ctrl activated?
- if ((mod_state & MOD_BIT(KC_LCTRL)) == MOD_BIT(KC_LCTRL)) {
+ if ((mod_state & MOD_BIT(KC_LCTL)) == MOD_BIT(KC_LCTL)) {
if (record->event.pressed) {
- // No need to register KC_LCTRL because it's already active.
- unregister_code(KC_LCTRL);
+ // No need to register KC_LCTL because it's already active.
+ unregister_code(KC_LCTL);
// Send substitute code
register_code(substitute_keycode);
// Update the boolean variable to reflect the status of the register